<?php
// $Id: TaxonomyAssistantFilter.inc,v 1.2 2010/03/11 13:38:47 pounard Exp $

/**
 * @file
 * Solace OG module filters implementation.
 */

class TaxonomyAssistantFilter extends AbstractAssistantFilter
{
  /**
   * (non-PHPdoc)
   * @see AbstractAssistantFilter#getTitle()
   */
  public function getTitle() {
    return "Filters by terms";
  }

  /**
   * (non-PHPdoc)
   * @see AbstractAssistantFilter#getDescription()
   */
  public function getDescription() {
    return "Allows to filter search using taxonomy terms";
  }

  /**
   * (non-PHPdoc)
   * @see AbstractAssistantFilter#isBoostAble()
   */
  public function isBoostAble() {
    return FALSE;
  }

  /**
   * (non-PHPdoc)
   * @see AbstractAssistantFilter#isEnabled($context)
   */
  public function isEnabled(AbstractAssistantContext $context) {
    // Check for existing vocabularies, and much more, for existing terms in
    // those.
    return (bool) db_result(db_query("SELECT 1 FROM {term_data} td JOIN {vocabulary} v ON v.vid = td.tid LIMIT 1"));
  }

  /**
   * (non-PHPdoc)
   * @see AbstractAssistantFilter#_build($context, $values, $query)
   */
  protected function _build(AbstractAssistantContext $context, &$values, SolrQuery $query) {
    if (!empty($values['tid'])) {
      $collection = new SolrTermCollection();
      $collection->setOperator(SolrOperator::OPERATOR_OR);
      foreach ($values['tid'] as $tid) {
        $collection->add(new SolrTerm($tid));
      }
      $filter = new SolrFieldFilter('tid', $collection);
      $filter->setExclusion(SolrOperator::OPERATOR_REQUIRE);
      $query->fq->add($filter);
    }
  }

  /**
   * (non-PHPdoc)
   * @see AbstractAssistantFilter#_form($context, $values)
   */
  protected function _form(AbstractAssistantContext $context, &$values = array()) {
    // $form = array();
    $form = array();

    $options = array(NULL => t('-- Select vocabulary --'));
    foreach (taxonomy_get_vocabularies() as $vid => $voc) {
      // Include vocabulary only if it has terms
      if (db_result(db_query("SELECT COUNT(*) FROM {term_data} WHERE vid = %d", array($vid)))) {
        $options[$vid] = check_plain($voc->name);
      }
    }

    $form['vid'] = array(
      '#type' => 'select',
      '#options' => $options,
      '#required' => TRUE,
      '#default_value' => (isset($values['vid']) ? $values['vid'] : NULL),
      '#weight' => 0,
    );
    $this->setAhahProperty($form['vid'], 'change');

    if (isset($values['vid']) && !empty($values['vid'])) {
      $form['tid'] = _taxonomy_term_select(NULL, 'name', NULL, $values['vid'], NULL, TRUE, NULL);
      $form['tid']['#required'] = TRUE;
      $form['tid']['#weight'] = 10;
      if (isset($values['tid'])) {
        $form['tid']['#default_value'] = $values['tid'];
      }
      if (!$form['tid']['#multiple']) {
        array_unshift($form['tid']['#options'], t('-- Select term --'));
      }
    }

    return $form;
  }

  /**
   * (non-PHPdoc)
   * @see AbstractAssistantFilter#isFilterQuery()
   */
  public function isFilterQuery() {
    return TRUE;
  }
}
